<template>
  <div
      id="account-detail"
      aria-labelledby="account-detail-tab"
      class="p-4 container mb-5 pb-5"
      role="tabpanel"
  >
    <template v-if="data.loaded">
      <div class="row">
        <div class="col-lg-10">
          <h3 class="d-flex align-items-center mb-3">
            <i class="fa-solid fa-car ms-2"></i>
            <span>{{ t('account.business.create.title', {name: data.type.title}) }}</span>
          </h3>
          <hr class="border-black mt-3 mb-4"/>
          <p class="text-muted lh-lg">{{ data.type.content }}</p>
          <p class="mt-2 mb-4 fw-bold text-muted">
            {{ t('account.business.create.subtitle', {name: data.type.title}) }}
          </p>
        </div>
      </div>
    </template>
    <template v-else>
      <div class="row">
        <div class="col-lg-10">
          <h3 class="d-flex align-items-center mb-3">
            <i class="fa-solid fa-car ms-2"></i>
            <client-only>
              <shimmer height="40" custom-class="w-200-px"></shimmer>
            </client-only>
          </h3>
          <hr class="border-black mt-3 mb-4"/>
          <p class="text-muted lh-lg">
            <client-only>
              <shimmer height="20" custom-class="my-3"></shimmer>
              <shimmer height="20" custom-class="my-3"></shimmer>
              <shimmer height="20" custom-class="my-3"></shimmer>
              <shimmer height="20" custom-class="my-3"></shimmer>
            </client-only>
          </p>
          <p class="mt-2 mb-4 fw-bold text-muted">
            <client-only>
              <shimmer height="20" custom-class="my-5"></shimmer>
            </client-only>
          </p>
        </div>
      </div>
    </template>

    <div class="row">
      <div class="col-sm-10">
        <form @submit.prevent="submitForm">
          <div class="row">
            <div class="mb-3 col-lg-6">
              <label class="mb-2 fw-bold" for="logo">
                <i class="fa-regular fa-image ms-1"></i>
                {{ t('account.business.create.fields.logo', {name: data.type.title}) }}
              </label>
              <input id="logo" class="form-control py-3" type="file" @change="uploadImage"/>
            </div>

            <div class="mb-3 col-lg-6">
              <label class="mb-2 fw-bold" for="name">
                <i class="fa-regular fa-circle-user ms-1"></i>
                {{ t('account.business.create.fields.full_name') }}
              </label>
              <form-input id="name" v-model="data.form.name" />
            </div>

            <div class="mb-3 col-lg-6">
              <label class="mb-2 fw-bold" for="melicode">
                <i class="fa-solid fa-image-portrait ms-1"></i>
                {{ t('account.business.create.fields.national_code') }}
              </label>
              <form-number dir="ltr" id="melicode" maxlength="10" v-model="data.form.melicode" />
            </div>

            <div class="mb-3 col-lg-6">
              <label class="mb-2 fw-bold" for="email">
                <i class="fa-regular fa-envelope ms-1"></i>
                {{ t('account.business.create.fields.email') }}
              </label>
              <form-input dir="ltr" id="email" v-model="data.form.email" />
            </div>

            <div class="mb-3 col-lg-6">
              <label class="mb-2 fw-bold" for="title">
                <i class="fa-solid fa-car"></i>
                {{ t('account.business.create.fields.business_name', {name: data.type.title}) }}
              </label>
              <form-input id="title" v-model="data.form.title" />
            </div>

            <div class="mb-3 col-lg-6">
              <label class="mb-2 fw-bold" for="tel">
                <i class="fa-solid fa-phone ms-1"></i>
                {{ t('account.business.create.fields.business_phone', {name: data.type.title}) }}
              </label>
              <form-input id="tel" dir="ltr" v-model="data.form.tel" />

            </div>

            <div class="mb-3 col-lg-12">
              <label class="mb-2 fw-bold" for="address">
                <i class="fa-solid fa-location-dot ms-1"></i>
                {{ t('account.business.create.fields.address') }}
              </label>
              <form-input id="address" v-model="data.form.address" />
            </div>

            <div class="mb-4 col-lg-12">
              <label class="mb-2 fw-bold d-block">
                <i class="fa-regular fa-image ms-1"></i>
                انتخاب پس‌زمینه
              </label>
              <div class="d-flex flex-wrap gap-3">
                <template v-if="data.loaded">
                  <div
                      v-for="(background,index) in data.backgrounds"
                      :key="index"
                      class="bg-option position-relative p-2"
                      :class="{ selected: data.selected_background === background.id }"
                      @click="data.selected_background = background.id"
                  >
                    <img :src="background.path" alt="background"/>
                    <i
                        v-if="data.selected_background === background.id"
                        class="fa-solid fa-circle-check selected-icon"
                    ></i>
                  </div>
                </template>
                <template v-else>
                  <div
                      v-for="i in 4"
                      :key="i"
                      class="bg-option position-relative my-2 p-2"
                  >
                    <client-only>
                      <shimmer height="300" custom-class="w-200-px"></shimmer>
                    </client-only>
                  </div>
                </template>
              </div>
            </div>

            <div class="mb-5 col-lg-12 pb-3">
              <label class="mb-2 fw-bold" for="content">
                <i class="fa-solid fa-circle-info ms-1"></i>
                {{ t('account.business.create.fields.about', {name: data.type.title}) }}
              </label>
              <client-only>
                <form-editor id="content" v-model="data.form.content"/>
              </client-only>
            </div>

            <div class="mt-5 col-lg-12">
              <button class="btn btn-default w-100 py-3" type="submit">
                {{ t('account.business.create.fields.submit') }}
              </button>
            </div>
          </div>
        </form>
      </div>
    </div>
  </div>
</template>

<script setup>
import {useI18n} from 'vue-i18n'
import {onMounted, reactive} from "vue";
import {useRoute, useRouter} from "vue-router";
import {useCookie} from "nuxt/app";

definePageMeta({
  layout: "default",
  middleware: ['auth']
});

// Variable
const {t} = useI18n()
const route = useRoute();
const router = useRouter();
const {$api, $sweetalert} = useNuxtApp();

// Data
const data = reactive({
  loaded: false,
  form: {
    name: "",
    melicode: "",
    title: "",
    tel: "",
    email: "",
    image: "",
    address: "",
    content: "",
  },
  selected_background: "",
  type: {},
  backgrounds: [],
});
const slug = ref(route.params.slug);

// Actions
const getBackground = async () => {
  await $api.post('/background', {}).then((value) => {
    data.backgrounds = [
      {
        id: 0,
        path: '/upload.png'
      },
      ...value.data.data
    ]
  })
}

const getType = async () => {
  data.loaded = false;
  await $api.post('/business_type/show', {slug:slug.value}).then((value) => {
    data.type = value.data.data;

    data.loaded = true;
  })
}

const uploadImage = (event) => {
  data.form.image = event.target.files[0];
};

const submitForm = async () => {
  const formData = new FormData()

  formData.append('name', data.form.name)
  formData.append('melicode', data.form.melicode)
  formData.append('title', data.form.title)
  formData.append('tel', data.form.tel)
  formData.append('email', data.form.email)
  formData.append('image', data.form.image)
  formData.append('address', data.form.address)
  formData.append('content', data.form.content)
  formData.append('business_type_id', data.type.id)

  // حتماً مقدار background_id رو ارسال کن (پیش‌فرض 0 برای زمانی که انتخاب نشده)
  formData.append('background_id', data.selected_background || 0)

  await $api.post('/user/business/create', formData).then((value) => {
    if (value.data.status) {
      $sweetalert.success(t('account.business.create.messages.success'))
      router.push('/account/business/upgrade/' + value.data.data.business_id )
    } else {
      $sweetalert.error(t('account.business.create.messages.failed'))
    }
  })
}

// Life Cycle
onMounted(() => {
  getBackground()
  getType();
});

</script>

<style scoped>

</style>
